<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="53"/>
        <location filename="../mainwindow.cpp" line="263"/>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>MX Cleanup</source>
        <translation>MX Cleanup</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Φάκελοι για καθαρισμό</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="566"/>
        <source>Delete Logs</source>
        <translation>Διαγραφή αρχείων καταγραφής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Old logs</source>
        <translation>Παλιά αρχεία καταγραφής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="591"/>
        <source>All logs</source>
        <translation>Όλα τα αρχεία καταγραφής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <location filename="../mainwindow.ui" line="411"/>
        <location filename="../mainwindow.ui" line="604"/>
        <source>Don&apos;t empty</source>
        <translation>Μην αδειάζετε</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="119"/>
        <source>Display help </source>
        <translation>Δείτε Βοήθεια</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>Help</source>
        <translation>Βοήθεια </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Alt+H</source>
        <translation>Alt+H </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>About this application</source>
        <translation>Περί εφαρμογής.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>About...</source>
        <translation>Περί</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Quit application</source>
        <translation>Κλείστε την εφαρμογή </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Apply</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Empty Trash</source>
        <translation>Άδειασμα κάδου απορριμμάτων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>Selected user</source>
        <translation>Επιλεγμένος χρήστης</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>All users</source>
        <translation>Ολοι οι χρήστες</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Trash older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <location filename="../mainwindow.ui" line="630"/>
        <source> days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="376"/>
        <source>Clear APT Cache</source>
        <translation>Εκκαθάριση του apt cache</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>Old files</source>
        <translation>Παλιά αρχεία</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>All files</source>
        <translation>Όλα τα αρχεία</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Free Disk Space for User</source>
        <translation>Ελεύτερο χώρο για το χρήστη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <location filename="../mainwindow.ui" line="465"/>
        <source>Select user to repair</source>
        <translation>Επιλέξτε το χρήστη για επισκευή
</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>Select user:</source>
        <translation>Επιλέξτε το χρήστη:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Γραφικό εργαλείο για την ανάλυση της χρήσης του δίσκου</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="490"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Εκτελέστε τον Disk Usage Analyzer </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Schedule</source>
        <translation>Δρομολόγιο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>No automatic clean</source>
        <translation>Δεν καθαρίζεται αυτόματα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Daily</source>
        <translation>Καθημερινά</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Weekly</source>
        <translation>Εβδομαδιαίος</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>Monthly</source>
        <translation>Μηνιαίος</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="646"/>
        <source>Logs older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Done</source>
        <translation>Ολοκληρώθηκε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>Cleanup command done</source>
        <translation>Η εντολή εκκαθάρισης ολοκληρώθηκε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB απελευθερώθηκαν</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>About</source>
        <translation>Περί</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>Version: </source>
        <translation>Έκδοση:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Quick and safe removal of old files</source>
        <translation>Γρήγορη και ασφαλής αφαίρεση παλιών αρχείων</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c)  MX Linux </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="291"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>You must run this program as root.</source>
        <translation>Πρέπει να τρέξετε αυτή την εφαρμογή ως Root.</translation>
    </message>
</context>
</TS>
